@@ -19,6 +19,6 @@ class BundlerTestCase(unittest.TestCase):
     def test_resolve_partition_path(self):
         bundler = Bundler(None)
 
-        bundler.partitions = {'test': ['package']}
-        self.assertEqual('/test', bundler._resolve_partition_path('package', '/'))
-        self.assertEqual('/', bundler._resolve_partition_path('package_2', '/'))
\ No newline at end of file
+        bundler.partitions = {"test": ["package"]}
+        self.assertEqual("/test", bundler._resolve_partition_path("package", "/"))
+        self.assertEqual("/", bundler._resolve_partition_path("package_2", "/"))
