@@ -5,11 +5,11 @@ class Config:
     def __init__(self, recipe):
         self.recipe = recipe
 
-        self.app_dir = os.path.abspath(self.recipe.get_item('AppDir/path'))
+        self.app_dir = os.path.abspath(self.recipe.get_item("AppDir/path"))
 
-        self.arch = self.recipe.get_item('AppDir/yum/arch')
-        self.include_list = self.recipe.get_item('AppDir/yum/include')
-        self.exclude_list = self.recipe.get_item('AppDir/yum/exclude', [])
+        self.arch = self.recipe.get_item("AppDir/yum/arch")
+        self.include_list = self.recipe.get_item("AppDir/yum/include")
+        self.exclude_list = self.recipe.get_item("AppDir/yum/exclude", [])
 
         self.cache_root = self._get_cache_dir()
         self.archives_path = self._get_archives_path()
@@ -19,7 +19,7 @@ class Config:
         os.makedirs(self.archives_path, exist_ok=True)
 
     def _get_cache_dir(self):
-        return os.path.abspath('appimage-builder-cache')
+        return os.path.abspath("appimage-builder-cache")
 
     def _get_archives_path(self):
-        return os.path.join(self.cache_root, 'yum', 'archives')
+        return os.path.join(self.cache_root, "yum", "archives")
