@@ -20,19 +20,19 @@ class FileError(RuntimeError):
 
 class File(Command):
     def __init__(self):
-        super().__init__('file')
+        super().__init__("file")
         self.log_stdout = False
         self.log_command = False
 
     def query(self, path):
-        self._run(['file', '-b', '--exclude', 'ascii', path])
+        self._run(["file", "-b", "--exclude", "ascii", path])
 
         if self.return_code != 0:
-            raise FileError('\n'.join(self.stderr))
+            raise FileError("\n".join(self.stderr))
 
-        return '\n'.join(self.stdout)
+        return "\n".join(self.stdout)
 
     def is_executable_elf(self, path):
         output = self.query(path)
-        result = ('ELF' in output) and ('executable' in output)
+        result = ("ELF" in output) and ("executable" in output)
         return result
