@@ -19,7 +19,7 @@ class YumDownloaderError(RuntimeError):
 
 class YumDownloader(Command):
     def __init__(self):
-        super().__init__('yumdownloader')
+        super().__init__("yumdownloader")
 
     def download(self, packages, dir, exclude=None):
         if exclude is None:
@@ -28,11 +28,11 @@ class YumDownloader(Command):
         command = self._get_yum_download_command(packages, exclude, dir)
         self._run(command)
         if self.return_code != 0:
-            raise YumDownloaderError('yumdownloader failed')
+            raise YumDownloaderError("yumdownloader failed")
 
     def _get_yum_download_command(self, packages, exclude, dir):
-        command = ['yumdownloader', '--resolve', '--destdir=%s' % dir]
-        command.extend([['-x', pkg] for pkg in exclude])
+        command = ["yumdownloader", "--resolve", "--destdir=%s" % dir]
+        command.extend([["-x", pkg] for pkg in exclude])
         command.extend(packages)
 
         return command
